/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.framework;

import org.fortiss.af3.component.model.InputPort;

/**
 * Generator extension for platform elements that can be read (e.g. sensors and busses). Each method
 * is provided a target variable by the calling code generator, which should be used to write the
 * read value into. Implementors are also provided a {@code postfix} and a {@code singletonPostfix}
 * if they also implement {@link IInstanceGeneratorExtension} and
 * {@link ISingletonGeneratorExtension}, respectively. The code generator also provides the deployed
 * {@link InputPort} in case an implementor needs additional data from the model (e.g. the type of
 * the input port).
 * 
 * @author hoelzl
 */
public interface IReadableGeneratorExtension {
	/** Returns the read code for the given port and target variable. */
	String getReadCode(String postfix, String singletonPostfix, InputPort logicalSignal,
			String targetVariable);

	/**
	 * Returns the read code to determine whether the value of the platform element is NoVal. May
	 * return {@code null}, to indicate that NoVal is not supported.
	 */
	String getNoValReadCode(String postfix, String singletonPostfix, InputPort logicalSignal);
}
